package com.ruoyi.tcZz.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.tcZz.domain.TcAqg;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.tcZz.mapper.TcQlzxxdsjtjMapper;
import com.ruoyi.tcZz.domain.TcQlzxxdsjtj;
import com.ruoyi.tcZz.service.ITcQlzxxdsjtjService;

/**
 * 清郎专项行动数据统计Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@Service
public class TcQlzxxdsjtjServiceImpl implements ITcQlzxxdsjtjService 
{
    @Autowired
    private TcQlzxxdsjtjMapper tcQlzxxdsjtjMapper;

    /**
     * 查询清郎专项行动数据统计
     * 
     * @param id 清郎专项行动数据统计主键
     * @return 清郎专项行动数据统计
     */
    @Override
    public TcQlzxxdsjtj selectTcQlzxxdsjtjById(Long id)
    {
        return tcQlzxxdsjtjMapper.selectTcQlzxxdsjtjById(id);
    }

    /**
     * 查询清郎专项行动数据统计列表
     * 
     * @param tcQlzxxdsjtj 清郎专项行动数据统计
     * @return 清郎专项行动数据统计
     */
    @Override
    public List<TcQlzxxdsjtj> selectTcQlzxxdsjtjList(TcQlzxxdsjtj tcQlzxxdsjtj)
    {
        return tcQlzxxdsjtjMapper.selectTcQlzxxdsjtjList(tcQlzxxdsjtj);
    }

    /**
     * 新增清郎专项行动数据统计
     * 
     * @param tcQlzxxdsjtj 清郎专项行动数据统计
     * @return 结果
     */
    @Override
    public int insertTcQlzxxdsjtj(TcQlzxxdsjtj tcQlzxxdsjtj)
    {
        tcQlzxxdsjtj.setCreateTime(DateUtils.getNowDate());
        return tcQlzxxdsjtjMapper.insertTcQlzxxdsjtj(tcQlzxxdsjtj);
    }

    /**
     * 修改清郎专项行动数据统计
     * 
     * @param tcQlzxxdsjtj 清郎专项行动数据统计
     * @return 结果
     */
    @Override
    public int updateTcQlzxxdsjtj(TcQlzxxdsjtj tcQlzxxdsjtj)
    {
        tcQlzxxdsjtj.setUpdateTime(DateUtils.getNowDate());
        return tcQlzxxdsjtjMapper.updateTcQlzxxdsjtj(tcQlzxxdsjtj);
    }

    /**
     * 批量删除清郎专项行动数据统计
     * 
     * @param ids 需要删除的清郎专项行动数据统计主键
     * @return 结果
     */
    @Override
    public int deleteTcQlzxxdsjtjByIds(Long[] ids)
    {
        return tcQlzxxdsjtjMapper.deleteTcQlzxxdsjtjByIds(ids);
    }

    /**
     * 删除清郎专项行动数据统计信息
     * 
     * @param id 清郎专项行动数据统计主键
     * @return 结果
     */
    @Override
    public int deleteTcQlzxxdsjtjById(Long id)
    {
        return tcQlzxxdsjtjMapper.deleteTcQlzxxdsjtjById(id);
    }

    @Override
    public String importUser(List<TcQlzxxdsjtj> tcQlzxxdsjtjList) {
        StringBuilder successMsg = new StringBuilder();
        if (!tcQlzxxdsjtjList.isEmpty()) {
            for (TcQlzxxdsjtj tcQlzxxdsjtj : tcQlzxxdsjtjList) {
                tcQlzxxdsjtjMapper.insertTcQlzxxdsjtj(tcQlzxxdsjtj);
            }
            successMsg.append("导入成功");
        }

        return successMsg.toString();
    }

    @Override
    public void updateByisStatus(Integer isStatus,List<String> ids) {
        tcQlzxxdsjtjMapper.updateByisStatus(isStatus,ids);
    }
}
