package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcQlzxxddt;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcQlzxxdsjtj;
import com.ruoyi.tcZz.service.ITcQlzxxdsjtjService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 清郎专项行动数据统计Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "清郎专项行动数据统计")
@RequestMapping("/tcZz/netManage/qlzxxdsjtj")
public class TcQlzxxdsjtjController extends BaseController {
    @Autowired
    private ITcQlzxxdsjtjService tcQlzxxdsjtjService;

    /**
     * 查询清郎专项行动数据统计列表
     */
    @ApiOperation(value = "查询清郎专项行动数据统计列表", response = TcQlzxxdsjtj.class)
    @GetMapping("/list")
    public TableDataInfo list(TcQlzxxdsjtj tcQlzxxdsjtj) {
        startPage();
        List<TcQlzxxdsjtj> list = tcQlzxxdsjtjService.selectTcQlzxxdsjtjList(tcQlzxxdsjtj);
        return getDataTable(list);
    }

    /**
     * 导出清郎专项行动数据统计列表
     */
    @ApiOperation(value = "导出清郎专项行动数据统计列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcQlzxxdsjtj tcQlzxxdsjtj) {
        List<TcQlzxxdsjtj> list = tcQlzxxdsjtjService.selectTcQlzxxdsjtjList(tcQlzxxdsjtj);
        ExcelUtil<TcQlzxxdsjtj> util = new ExcelUtil<TcQlzxxdsjtj>(TcQlzxxdsjtj.class);
        util.exportExcel(response, list, "清郎专项行动数据统计数据");
    }

    /**
     * 获取清郎专项行动数据统计详细信息
     */
    @ApiOperation(value = "获取清郎专项行动数据统计详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcQlzxxdsjtjService.selectTcQlzxxdsjtjById(id));
    }

    /**
     * 新增清郎专项行动数据统计
     */
    @ApiOperation(value = "新增清郎专项行动数据统计")
    @PostMapping
    public AjaxResult add(@RequestBody TcQlzxxdsjtj tcQlzxxdsjtj) {
        return toAjax(tcQlzxxdsjtjService.insertTcQlzxxdsjtj(tcQlzxxdsjtj));
    }

    /**
     * 修改清郎专项行动数据统计
     */
    @ApiOperation(value = "修改清郎专项行动数据统计")
    @PutMapping
    public AjaxResult edit(@RequestBody TcQlzxxdsjtj tcQlzxxdsjtj) {
        return toAjax(tcQlzxxdsjtjService.updateTcQlzxxdsjtj(tcQlzxxdsjtj));
    }

    /**
     * 删除清郎专项行动数据统计
     */
    @ApiOperation(value = "删除清郎专项行动数据统计")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcQlzxxdsjtjService.deleteTcQlzxxdsjtjByIds(ids));
    }

    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcQlzxxdsjtj> util = new ExcelUtil<TcQlzxxdsjtj>(TcQlzxxdsjtj.class);
        List<TcQlzxxdsjtj> tcQlzxxdsjtjList = util.importExcel(file.getInputStream());
        tcQlzxxdsjtjService.importUser(tcQlzxxdsjtjList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcQlzxxdsjtjService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcQlzxxdsjtj> util = new ExcelUtil<TcQlzxxdsjtj>(TcQlzxxdsjtj.class);
        util.importTemplateExcel(response, " 清郎专项行动数据统计");
    }
}
